/*
 * SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
 *
 * SPDX-License-Identifier: LGPL-3.0-or-later
 */

#pragma once

#include "linglong/adaptors/package_manager/gen_org_deepin_linglong_packagemanager1.h"

namespace linglong::adaptors::package_manger {
using PackageManager1 = OrgDeepinLinglongPackagemanager1Adaptor;
}
